#ifndef NT2_INCLUDE_FUNCTIONS_CIRCUL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CIRCUL_HPP_INCLUDED

#include <nt2/gallery/include/functions/circul.hpp>

#endif
